Stan Math Library: stan/math/prim/scal/fun/promote_scalar_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

promote_scalar_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_PROMOTE_SCALAR_TYPE_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_PROMOTE_SCALAR_TYPE_HPP
3
4 namespace stan {
5 namespace math {
6
14 template <typename T, typename S>
15 struct promote_scalar_type {
19 typedef T type;
20 };
21
22 }
23 }
24 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::promote_scalar_type
Template metaprogram to calculate a type for converting a convertible type.
Definition: promote_scalar_type.hpp:15
stan::math::promote_scalar_type::type
T type
The promoted type.
Definition: promote_scalar_type.hpp:19

[ Stan Home Page ] © 2011–2016, Stan Development Team.